//
//  YHPreviewViewModel.swift
//  galaxy
//
//  Created by davidhuangA on 2024/3/3.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHPreviewViewModel: YHBaseViewModel {
    //其他信息 预览
    private var otherInfoPreviewModel : YHPreviewForOtherInfoModel?
    var arrDataForOtherInfo : [YHPreviewInfoSessionModel] = []
    
    //基本资料 预览
    private var basiceInfoPreviewModel : YHBasicInfoFillModel?
    var arrDataForBasicInfo : [YHPreviewInfoSessionModel] = []
}

extension YHPreviewViewModel {
    
    //获取基本资料预览 数据
    func getPreviewForBasicInfo( params:[String : Any],callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Basics.basicInfoApi
        
        let _ = YHNetRequest.getRequest(url: strUrl,params: params) { [weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            printLog("model 是 ==> \(json)")
            
            if json.code == 200 {
                let dic = json.data
                guard let resultModel = YHBasicInfoFillModel.deserialize(dict: dic as? [AnyHashable : Any]) else {
                    callBackBlock(false,nil)
                    return
                }
                
                self.basiceInfoPreviewModel = resultModel
                //根据返回值 组装 真实的数据
                installDataForBasicInfo()
                
                callBackBlock(true,nil)
            } else {
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code),errorMsg: json.msg)
                callBackBlock(false,error)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
    
    //获取其他信息预览 数据
    func getPreviewForOtherInfo( params:[String : Any],callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {

        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Preview.PreviewOtherInfoApi
        let _ = YHNetRequest.getRequest(url: strUrl,params: params) { [weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            
            if json.code == 200 {
                let dic = json.data
                guard let resultModel = YHPreviewForOtherInfoModel.deserialize(dict: dic as? [AnyHashable : Any]) else {
                    callBackBlock(false,nil)
                    return
                }
                
                self.otherInfoPreviewModel = resultModel
                
                installDataForOtherInfo()
                
                //根据返回值 组装 真实的数据
                callBackBlock(true,nil)
                
            } else {
                let err : YHErrorModel = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg)
                callBackBlock(false,err)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
}
private extension YHPreviewViewModel {
    //组装 基本资料预览 数据
    func installDataForBasicInfo() {
        do {
            //主申请人
            if let model = basiceInfoPreviewModel?.applicant {
                let answer0 = model.has_conviction?.has == "Y" ? "是" : "否"
                let remark0 = answer0 == "是" ? (model.has_conviction?.info ?? "") : nil
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾在香港或其他地方因任何罪行或违法行为被被定罪：", answer: answer0,remark: remark0)
                
                
                let answer1 = model.has_departure?.has == "Y" ? "是" : "否"
                let remark1 = answer1 == "是" ? (model.has_conviction?.info ?? "") : nil
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾在香港或其他地方被拒入境/递解/遣送或要求离境？", answer: answer1,remark: remark1)
                
                
                let answer2 = model.has_deny?.has == "Y" ? "是" : "否"
                let remark2 = answer2 == "是" ? (model.has_deny?.info ?? "") : nil
                let tmp2 = YHPreviewQuestionAndAnswerModel(question: "3、是否曾被拒绝签发香港或其他地方的签证/进入许可？", answer: answer2,remark: remark2)
                
                
                let answer3 = model.has_breaking_law?.has == "Y" ? "是" : "否"
                let remark3 = answer3 == "是" ? (model.has_breaking_law?.info ?? "") : nil
                let tmp3 = YHPreviewQuestionAndAnswerModel(question: "4、是否曾触犯香港或任何地方的入境法例？", answer: answer3,remark:remark3)
                
                let answer4 = model.has_other_id?.has == "Y" ? "是" : "否"
                let remark4 = answer4 == "是" ? (model.has_other_id?.info ?? "") : nil
                let tmp4 = YHPreviewQuestionAndAnswerModel(question: "5、是否曾经使用另一个姓名或身份申请香港入境签证/进入许可或进入香港？", answer: answer4,remark: remark4)
                
                let arr = [tmp0,tmp1,tmp2,tmp3,tmp4]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "主申请人", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
        
        
        do {
            //子女-1
            
            //子女 - xxx
            if let arrChild = basiceInfoPreviewModel?.child {
                for (index,model) in arrChild.enumerated() {
                    let answer0 = model.child_departure?.has == "Y" ? "是" : "否"
                    let remark0 = answer0 == "是" ? (model.child_departure?.info ?? "") : nil
                    
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾被拒绝入境/递解/遣送或要求离开香港？", answer: answer0,remark:remark0)
                    
                    
                    let answer1 = model.child_deny?.has == "Y" ? "是" : "否"
                    let remark1 = answer1 == "是" ? (model.child_deny?.info ?? "") : nil
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾被拒绝签发签证/进入许可以入境香港？", answer: answer1,remark: remark1)
                    let arr = [tmp0,tmp1]
                    
                    
                    let title = "子女" + "-" + model.subset_name
                    let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: title, cellData0: arr)
                    arrDataForBasicInfo.append(model1)
                }
            }
        }
        
        
        
        do {
            //配偶
            if let model = basiceInfoPreviewModel?.spouse {
                let answer0 = model.child_departure?.has == "Y" ? "是" : "否"
                let remark0 = answer0 == "是" ? (model.child_departure?.info ?? "") : nil
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾被拒绝入境/递解/遣送或要求离开香港？", answer: answer0,remark:remark0)
                
                let answer1 = model.child_deny?.has == "Y" ? "是" : "否"
                let remark1 = answer1 == "是" ? (model.child_deny?.info ?? "") : nil
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾被拒绝签发签证/进入许可以入境香港？", answer: answer1,remark: remark1)
                let arr = [tmp0,tmp1]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "配偶", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
        
        do {
            //家庭背景
            if let model = basiceInfoPreviewModel?.background {
                let answer0 = model.background_member?.has == "Y" ? "满足" : "不满足"
                let remark0 = answer0 == "满足" ? (model.background_member?.info ?? "") : nil
                
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、至少一名直系家庭成员（已婚配偶、父母、兄弟姐妹、子女）是现居于香港的香港永久性居民", answer:answer0,remark: remark0) //需要完善 for test hjl todo???
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "家庭背景", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
    }
    
    //组装 其他信息预览 数据
    func installDataForOtherInfo() {
        guard let model = otherInfoPreviewModel else {
            return
        }
        
        handleDataForOtherInfo()
        
        do {
            
            if let arr1 = model.list,arr1.isEmpty == false {
                var arr : [YHPersonInfoCellModel1] = []
                for (index,item) in arr1.enumerated() {
                    
                    //居住信息
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "开始时间：", answer: item.start_time)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "结束时间：", answer: item.end_time)
                    let title = "国家" + String(index + 1) + ":" + item.country
                    let model0 = YHPersonInfoCellModel1(cellTitle: title, cellData: [tmp0,tmp1])
                    
                    arr.append(model0)
                }
                
                let model3 = YHPreviewInfoSessionModel(cellType: .idCardInfoType, cellTitle: "居住信息", cellData1: arr)
                arrDataForOtherInfo.append(model3)
            }
        }
        
        
        do {
            //语言能力
            
            if let model = otherInfoPreviewModel?.language {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: model.levelDes, answer: model.remark)
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "语言能力", cellData0: arr)
                arrDataForOtherInfo.append(model1)
                
            }
        }
        
        do {
            //专业技能行业
            if let model = otherInfoPreviewModel?.profession {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、最能代表你的专业技能的行业是？（单选）", answer: model.optionDes,remark: model.remark)
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "专业技能行业", cellData0: arr)
                arrDataForOtherInfo.append(model1)
            }
        }
        
        do {
            //其他问题
            if let model = otherInfoPreviewModel?.question {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、您是否有行业内的专业资格证书？", answer: model.professional_qualification == 1 ? "是" : "否")
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、您是否在期刊或杂志上发表论文、文章、书籍等（与工作、资质有关的）？", answer: model.paper == 1 ? "是" : "否")
                let tmp2 = YHPreviewQuestionAndAnswerModel(question: "3、您是否有大学奖学金证明、专利证书、获奖证书（工作单位颁发的可以）？", answer: model.scholarship == 1 ? "是" : "否")
                let tmp3 = YHPreviewQuestionAndAnswerModel(question: "4、您是否被媒体采访过，专访您的文章被发表在杂志上或网络上？", answer: model.media_interview == 1 ? "是" : "否")
                let tmp4 = YHPreviewQuestionAndAnswerModel(question: "5、专业奖项：", answer: model.professional_awards)
                let tmp5 = YHPreviewQuestionAndAnswerModel(question: "6、学业奖项：", answer: model.academic_awards)
                let tmp6 = YHPreviewQuestionAndAnswerModel(question: "7、其他资料：", answer: model.other_information)
                let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "辅助资料", cellData0: arr)
                arrDataForOtherInfo.append(model1)
            }
        }
    }
}


private extension YHPreviewViewModel {
    //特殊处理 其他信息预览 需要的数据
    func handleDataForOtherInfo() {
        if let language = otherInfoPreviewModel?.language {
            if language.level > 0 {
                let target = String(language.level)
                for(_,item) in YHOtherInfoFillViewModel.arrLanguage.enumerated() {
                    
                    if target == item["id"] {
                        language.levelDes = item["title"] ?? "--"
                        language.remark = item["dec"] ?? "--"
                        break
                    }
                }
            }
        }
        
        
        
        if let profession = otherInfoPreviewModel?.profession {
            if profession.option > 0 {
                let target = String(profession.option)
                for(_,item) in YHOtherInfoFillViewModel.arrSkill.enumerated() {
                    
                    if target == item["value"] {
                        profession.optionDes = item["title"] ?? "--"
                        break
                    }
                }
            }
        }
    }
}
